===============================
Thematic tutorial document tree
===============================

.. toctree::
   :maxdepth: 2

   algebraic_combinatorics
   sandpile
   group_theory
   lie
   vector_calculus
   linear_programming
   numtheory_rsa
   coding_theory
   structures_in_coding_theory
   geometry
   steenrod_algebra_modules
   tutorial-programming-python
   tutorial-comprehensions
   tutorial-objects-and-classes
   functional_programming
   coercion_and_categories
   tutorial-implementing-algebraic-structures
   cython_interface
   numerical_sage/index
   explicit_methods_in_number_theory/index
   profiling
   sws2rst
